@@ -5,9 +5,10 @@ import sys
 def main():
     os.environ.setdefault(
         "DJANGO_SETTINGS_MODULE",
-        "{}.settings".format(os.environ.get('SITE_MODULE', 'leprikon.site')),
+        "{}.settings".format(os.environ.get("SITE_MODULE", "leprikon.site")),
     )
     from django.core.management import execute_from_command_line
+
     execute_from_command_line(sys.argv)
 
 
