@@ -11,7 +11,7 @@ from django.utils.translation import ugettext_lazy as _
 from ..models.orderables import Orderable, OrderableDiscount, OrderableRegistration
 from ..models.schoolyear import SchoolYear
 from ..models.subjects import SubjectType
-from ..utils import currency
+from ..utils import attributes, currency
 from .pdf import PdfExportAdminMixin
 from .subjects import SubjectBaseAdmin, SubjectDiscountBaseAdmin, SubjectRegistrationBaseAdmin
 
@@ -69,18 +69,17 @@ class OrderableAdmin(SubjectBaseAdmin):
         "copy_to_school_year",
     )
 
+    @attributes(short_description=_("Publish selected orderable events"))
     def publish(self, request, queryset):
         Orderable.objects.filter(id__in=[reg["id"] for reg in queryset.values("id")]).update(public=True)
         self.message_user(request, _("Selected orderable events were published."))
 
-    publish.short_description = _("Publish selected orderable events")
-
+    @attributes(short_description=_("Unpublish selected orderable events"))
     def unpublish(self, request, queryset):
         Orderable.objects.filter(id__in=[reg["id"] for reg in queryset.values("id")]).update(public=False)
         self.message_user(request, _("Selected orderable events were unpublished."))
 
-    unpublish.short_description = _("Unpublish selected orderable events")
-
+    @attributes(short_description=_("Copy selected orderable events to another school year"))
     def copy_to_school_year(self, request, queryset):
         class SchoolYearForm(forms.Form):
             school_year = forms.ModelChoiceField(
@@ -126,8 +125,6 @@ class OrderableAdmin(SubjectBaseAdmin):
             ),
         )
 
-    copy_to_school_year.short_description = _("Copy selected orderable events to another school year")
-
     def get_message_recipients(self, request, queryset):
         return (
             get_user_model()
@@ -146,6 +143,7 @@ class OrderableRegistrationAdmin(PdfExportAdminMixin, SubjectRegistrationBaseAdm
         SubjectRegistrationBaseAdmin.list_display[:3] + ("event_date",) + SubjectRegistrationBaseAdmin.list_display[3:]
     )
 
+    @attributes(short_description=_("Add discounts to selected registrations"))
     def add_discounts(self, request, queryset):
         ABSOLUTE = "A"
         RELATIVE = "R"
@@ -204,8 +202,7 @@ class OrderableRegistrationAdmin(PdfExportAdminMixin, SubjectRegistrationBaseAdm
             ),
         )
 
-    add_discounts.short_description = _("Add discounts to selected registrations")
-
+    @attributes(allow_tags=True, short_description=_("discounts"))
     def discounts(self, obj: OrderableRegistration):
         return format_html(
             '<a href="{href_list}"><b>{amount}</b></a>'
@@ -218,9 +215,7 @@ class OrderableRegistrationAdmin(PdfExportAdminMixin, SubjectRegistrationBaseAdm
             title_add=_("add discount"),
         )
 
-    discounts.allow_tags = True
-    discounts.short_description = _("discounts")
-
+    @attributes(allow_tags=True, short_description=_("received payments"))
     def received_payments(self, obj: OrderableRegistration):
         return format_html(
             '<a style="color: {color}" href="{href_list}" title="{title}"><b>{amount}</b></a>'
@@ -236,9 +231,6 @@ class OrderableRegistrationAdmin(PdfExportAdminMixin, SubjectRegistrationBaseAdm
             title_add=_("add payment"),
         )
 
-    received_payments.allow_tags = True
-    received_payments.short_description = _("received payments")
-
 
 @admin.register(OrderableDiscount)
 class OrderableDiscountAdmin(PdfExportAdminMixin, SubjectDiscountBaseAdmin):
