@@ -7,11 +7,14 @@ from django.utils.text import slugify
 from django.utils.translation import ugettext_lazy as _
 from PyPDF2 import PdfFileReader, PdfFileWriter
 
+from ..utils import attributes
+
 
 class PdfExportAdminMixin:
     actions = ("export_pdf",)
     pdf_event = "pdf"
 
+    @attributes(short_description=_("Export selected items in single PDF"))
     def export_pdf(self, request, queryset):
         # create PDF
         writer = PdfFileWriter()
@@ -34,28 +37,32 @@ class PdfExportAdminMixin:
 
         return response
 
-    export_pdf.short_description = _("Export selected items in single PDF.")
-
     def get_urls(self):
         urls = super().get_urls()
         return [
             urls_url(
-                r"(?P<obj_id>\d+).pdf$",
+                r"(?P<obj_id>\d+)-(?P<event>.+)\.pdf$",
+                self.admin_site.admin_view(self.pdf),
+                name="{}_{}_event_pdf".format(self.model._meta.app_label, self.model._meta.model_name),
+            ),
+            urls_url(
+                r"(?P<obj_id>\d+)\.pdf$",
                 self.admin_site.admin_view(self.pdf),
                 name="{}_{}_pdf".format(self.model._meta.app_label, self.model._meta.model_name),
-            )
+            ),
         ] + urls
 
-    def pdf(self, request, obj_id):
+    def pdf(self, request, obj_id, event=pdf_event):
         obj = self.get_object(request, obj_id)
 
         # create PDF response object
         response = HttpResponse(content_type="application/pdf")
-        response["Content-Disposition"] = 'attachment; filename="{}"'.format(obj.get_pdf_filename(self.pdf_event))
+        response["Content-Disposition"] = 'attachment; filename="{}"'.format(obj.get_pdf_filename(event))
 
         # write PDF to response
-        return obj.write_pdf(self.pdf_event, response)
+        return obj.write_pdf(event, response)
 
+    @attributes(allow_tags=True, short_description=_("download"))
     def download_tag(self, obj):
         return '<a href="{}">PDF</a>'.format(
             reverse(
@@ -63,6 +70,3 @@ class PdfExportAdminMixin:
                 args=(obj.id,),
             )
         )
-
-    download_tag.short_description = _("download")
-    download_tag.allow_tags = True
