@@ -21,7 +21,14 @@ class EventStatsForm(FormMixin, forms.Form):
         label=_("Events"),
     )
     paid_only = forms.BooleanField(label=_("Count only paid registrations"), required=False)
+    paid_later = forms.BooleanField(label=_("Count registrations paid later"), required=False)
+    approved_later = forms.BooleanField(label=_("Count registrations approved later"), required=False)
     unique_participants = forms.BooleanField(label=_("Count only unique participants"), required=False)
+    min_days = forms.IntegerField(
+        label=_("Minimal number of days"),
+        help_text=_("Count only participants attending events that last at least this number of days."),
+        required=False,
+    )
 
     def __init__(self, *args, **kwargs):
         school_year = kwargs.pop("school_year")
