@@ -7,6 +7,7 @@ from django.core.exceptions import ValidationError
 from django.db import transaction
 from django.db.models import Q
 from django.forms.models import inlineformset_factory
+from django.forms.widgets import Media
 from django.utils.functional import cached_property
 from django.utils.timezone import now
 from django.utils.translation import ugettext_lazy as _
@@ -57,7 +58,7 @@ class SubjectFilterForm(FormMixin, forms.Form):
     days_of_week = forms.MultipleChoiceField(
         label=_("Day of week"), choices=tuple(sorted(DAY_OF_WEEK.items())), required=False
     )
-    past = forms.BooleanField(label=_("Include past subjects"), required=False)
+    past = forms.BooleanField(label=_("Show past"), required=False)
     reg_active = forms.BooleanField(label=_("Available for registration"), required=False)
     invisible = forms.BooleanField(label=_("Show invisible"), required=False)
 
@@ -72,7 +73,9 @@ class SubjectFilterForm(FormMixin, forms.Form):
         self.subject_type_type = subject_type_type
 
         # pre filter subjects by initial params
-        qs = self._models[subject_type_type].objects.filter(school_year=school_year)
+        qs = self._models[subject_type_type].objects
+        if subject_type_type != SubjectType.EVENT or data.get("past"):
+            qs = qs.filter(school_year=school_year)
         if len(subject_types) == 1:
             qs = qs.filter(subject_type=subject_types[0])
         else:
@@ -165,8 +168,11 @@ class SubjectFilterForm(FormMixin, forms.Form):
             qs = qs.filter(target_groups__in=self.cleaned_data["target_groups"])
         if self.cleaned_data.get("days_of_week"):
             qs = qs.filter(times__day_of_week__in=self.cleaned_data["days_of_week"])
-        if self.subject_type_type == SubjectType.EVENT and not self.cleaned_data["past"]:
-            qs = qs.filter(end_date__gte=now())
+        if self.subject_type_type == SubjectType.EVENT:
+            if self.cleaned_data["past"]:
+                qs = qs.filter(end_date__lte=now()).order_by("-start_date", "-start_time")
+            else:
+                qs = qs.filter(end_date__gte=now())
         if self.cleaned_data["reg_active"]:
             qs = qs.filter(reg_from__lte=now()).exclude(reg_to__lte=now()).exclude(price=None)
         return qs.distinct()
@@ -395,9 +401,16 @@ class RegistrationParticipantForm(FormMixin, RegistrationParticipantFormMixin, S
         self.questions_form = type(
             str("QuestionsForm"),
             (FormMixin, forms.Form),
-            dict((q.name, q.get_field()) for q in self.subject.all_questions),
+            dict((q.slug, q.get_field()) for q in self.subject.all_questions),
         )(**kwargs)
 
+    @cached_property
+    def media(self):
+        media = Media()
+        for form in self.required_forms:
+            media = media + form.media
+        return media
+
     @cached_property
     def required_forms(self):
         return [
@@ -471,6 +484,9 @@ class RegistrationParticipantForm(FormMixin, RegistrationParticipantFormMixin, S
             "health",
         ]:
             setattr(participant, attr, getattr(self.instance, attr))
+        participant_answers = participant.get_answers()
+        participant_answers.update(self.instance.get_answers())
+        participant.answers = dumps(participant_answers)
         participant.save()
 
         # save / update first parent
@@ -525,9 +541,16 @@ class RegistrationGroupForm(FormMixin, SchoolMixin, forms.ModelForm):
         self.questions_form = type(
             str("QuestionsForm"),
             (FormMixin, forms.Form),
-            dict((q.name, q.get_field()) for q in self.subject.all_questions),
+            dict((q.slug, q.get_field()) for q in self.subject.all_questions),
         )(**kwargs)
 
+    @cached_property
+    def media(self):
+        media = Media()
+        for form in self.required_forms:
+            media = media + form.media
+        return media
+
     @cached_property
     def required_forms(self):
         return [
@@ -684,6 +707,13 @@ class RegistrationForm(FormMixin, forms.ModelForm):
         kwargs["prefix"] = "billing_info"
         self.billing_info_form = RegistrationBillingInfoForm(**kwargs)
 
+    @cached_property
+    def media(self):
+        media = Media()
+        for form in self.all_forms:
+            media = media + form.media
+        return media
+
     @cached_property
     def required_forms(self):
         return [
@@ -905,14 +935,14 @@ class RegistrationParticipantAdminForm(RegistrationParticipantFormMixin, SchoolA
         questions = self.obj.all_questions if self.obj else self.subject.all_questions
         answers = instance.get_answers() if instance else {}
         for q in questions:
-            self.fields["q_" + q.name].initial = answers.get(q.name)
+            self.fields["q_" + q.slug].initial = answers.get(q.slug)
 
         self._setup_required_fields()
 
     def save(self, commit=True):
         self.instance.answers = dumps(
             {
-                q.name: self.cleaned_data["q_" + q.name]
+                q.slug: self.cleaned_data["q_" + q.slug]
                 for q in (self.obj.all_questions if self.obj else self.subject.all_questions)
             }
         )
@@ -932,12 +962,12 @@ class RegistrationGroupAdminForm(SchoolAdminMixin, forms.ModelForm):
         questions = self.obj.all_questions if self.obj else self.subject.all_questions
         answers = instance.get_answers() if instance else {}
         for q in questions:
-            self.fields["q_" + q.name].initial = answers.get(q.name)
+            self.fields["q_" + q.slug].initial = answers.get(q.slug)
 
     def save(self, commit=True):
         self.instance.answers = dumps(
             {
-                q.name: self.cleaned_data["q_" + q.name]
+                q.slug: self.cleaned_data["q_" + q.slug]
                 for q in (self.obj.all_questions if self.obj else self.subject.all_questions)
             }
         )
