@@ -32,7 +32,7 @@ from filer.fields.image import FilerImageField
 from multiselectfield import MultiSelectField
 
 from ..conf import settings
-from ..utils import FEMALE, MALE, comma_separated, currency, lazy_paragraph as paragraph, localeconv, spayd
+from ..utils import FEMALE, MALE, attributes, comma_separated, currency, lazy_paragraph as paragraph, localeconv, spayd
 from .agegroup import AgeGroup
 from .agreements import Agreement, AgreementOption
 from .citizenship import Citizenship
@@ -146,6 +146,14 @@ class SubjectType(models.Model):
         related_name="+",
         verbose_name=_("registration print setup"),
     )
+    decision_print_setup = models.ForeignKey(
+        PrintSetup,
+        blank=True,
+        null=True,
+        on_delete=models.SET_NULL,
+        related_name="+",
+        verbose_name=_("decision print setup"),
+    )
     pr_print_setup = models.ForeignKey(
         PrintSetup,
         blank=True,
@@ -437,6 +445,15 @@ class Subject(TimesMixin, models.Model):
         verbose_name=_("registration print setup"),
         help_text=_("Only use to set value specific for this subject."),
     )
+    decision_print_setup = models.ForeignKey(
+        PrintSetup,
+        blank=True,
+        null=True,
+        on_delete=models.SET_NULL,
+        related_name="+",
+        verbose_name=_("registration print setup"),
+        help_text=_("Only use to set value specific for this subject."),
+    )
     pr_print_setup = models.ForeignKey(
         PrintSetup,
         blank=True,
@@ -592,26 +609,22 @@ class Subject(TimesMixin, models.Model):
     def get_edit_url(self):
         return reverse("admin:leprikon_{}_change".format(self.subject._meta.model_name), args=(self.id,))
 
+    @attributes(short_description=_("age groups list"))
     def get_age_groups_list(self):
         return comma_separated(self.all_age_groups)
 
-    get_age_groups_list.short_description = _("age groups list")
-
+    @attributes(short_description=_("groups list"))
     def get_groups_list(self):
         return comma_separated(self.all_groups)
 
-    get_groups_list.short_description = _("groups list")
-
+    @attributes(short_description=_("leaders list"))
     def get_leaders_list(self):
         return comma_separated(self.all_leaders)
 
-    get_leaders_list.short_description = _("leaders list")
-
+    @attributes(short_description=_("target groups list"))
     def get_target_groups_list(self):
         return comma_separated(self.all_target_groups)
 
-    get_target_groups_list.short_description = _("target groups list")
-
     def get_print_setup(self, event):
         return PrintSetup()
 
@@ -835,32 +848,28 @@ class SubjectRegistration(PdfExportAndMailMixin, models.Model):
     def all_participants(self):
         return list(self.participants.all())
 
+    @attributes(short_description=_("participants"))
     def participants_list(self):
         return "\n".join(map(str, self.all_participants))
 
-    participants_list.short_description = _("participants")
-
+    @attributes(short_description=_("participants"))
     def participants_list_html(self):
         if self.all_participants:
             return mark_safe("<br/>".join(map(str, self.all_participants)))
         return self.group_members_list_html()
 
-    participants_list_html.short_description = _("participants")
-
     @cached_property
     def all_group_members(self):
         return list(self.group_members.all())
 
+    @attributes(short_description=_("group members"))
     def group_members_list(self):
         return "\n".join(map(str, self.all_group_members))
 
-    group_members_list.short_description = _("group members")
-
+    @attributes(short_description=_("group members"))
     def group_members_list_html(self):
         return mark_safe("<br/>".join(map(str, self.all_group_members)))
 
-    group_members_list_html.short_description = _("group members")
-
     @cached_property
     def all_questions(self):
         return list(self.questions.all())
@@ -873,6 +882,7 @@ class SubjectRegistration(PdfExportAndMailMixin, models.Model):
     def all_agreement_options(self):
         return list(self.agreement_options.all())
 
+    @attributes(short_description=_("agreement options"))
     def agreement_options_list(self):
         lines = []
         for agreement in self.all_agreements:
@@ -886,8 +896,6 @@ class SubjectRegistration(PdfExportAndMailMixin, models.Model):
                 )
         return "\n".join(lines)
 
-    agreement_options_list.short_description = _("agreement options")
-
     @cached_property
     def all_attachments(self):
         return self.subject.all_attachments + self.subject.subject_type.all_attachments
@@ -1044,7 +1052,9 @@ class SubjectRegistration(PdfExportAndMailMixin, models.Model):
     def get_pdf_filename(self, event):
         if event == "payment_request":
             return basename(self.get_payment_request_url())
-        return self.slug + ".pdf"
+        if event == "pdf":
+            return f"{self.slug}.pdf"
+        return f"{self.slug}-{event}.pdf"
 
     def get_discounted(self, d=None):
         return sum(p.amount for p in self.get_discounts(d))
@@ -1194,6 +1204,13 @@ class SubjectRegistration(PdfExportAndMailMixin, models.Model):
                 or LeprikonSite.objects.get_current().pr_print_setup
                 or PrintSetup()
             )
+        if event == "decision":
+            return (
+                self.subject.decision_print_setup
+                or self.subject.subject_type.decision_print_setup
+                or LeprikonSite.objects.get_current().decision_print_setup
+                or PrintSetup()
+            )
         return (
             self.subject.reg_print_setup
             or self.subject.subject_type.reg_print_setup
@@ -1235,7 +1252,7 @@ class QuestionsMixin:
         for q in self.registration.all_questions:
             yield {
                 "question": q.question,
-                "answer": answers.get(q.name, ""),
+                "answer": answers.get(q.slug, ""),
             }
 
 
@@ -1326,10 +1343,15 @@ class SubjectRegistrationParticipant(SchoolMixin, PersonMixin, QuestionsMixin, m
             birth_year=self.birth_date.year,
         )
 
+    @cached_property
+    def key(self):
+        return (self.first_name.lower(), self.last_name.lower(), self.birth_date)
+
     @cached_property
     def parents(self):
         return list(p for p in [self.parent1, self.parent2] if p is not None)
 
+    @attributes(short_description=_("first parent"))
     @cached_property
     def parent1(self):
         if self.has_parent1:
@@ -1337,8 +1359,7 @@ class SubjectRegistrationParticipant(SchoolMixin, PersonMixin, QuestionsMixin, m
         else:
             return None
 
-    parent1.short_description = _("first parent")
-
+    @attributes(short_description=_("second parent"))
     @cached_property
     def parent2(self):
         if self.has_parent2:
@@ -1346,8 +1367,6 @@ class SubjectRegistrationParticipant(SchoolMixin, PersonMixin, QuestionsMixin, m
         else:
             return None
 
-    parent2.short_description = _("second parent")
-
     @cached_property
     def all_recipients(self):
         # don't use unverified emails
@@ -1496,12 +1515,11 @@ class SubjectRegistrationBillingInfo(models.Model):
     def __str__(self):
         return self.name
 
+    @attributes(short_description=_("address"))
     @cached_property
     def address(self):
         return ", ".join(filter(bool, (self.street, self.city, self.postal_code)))
 
-    address.short_description = _("address")
-
 
 class SubjectDiscount(AbstractTransaction):
     amount = PriceField(_("discount"), default=0)
@@ -1601,12 +1619,11 @@ class SubjectReceivedPayment(SubjectPaymentMixin, Transaction):
     def real_amount(self):
         return self.amount
 
+    @attributes(short_description=_("target registration"))
     @cached_property
     def registration(self):
         return self.target_registration
 
-    registration.short_description = _("target registration")
-
 
 class SubjectReturnedPayment(SubjectPaymentMixin, Transaction):
     object_name = "returned_payment"
@@ -1621,12 +1638,11 @@ class SubjectReturnedPayment(SubjectPaymentMixin, Transaction):
     def real_amount(self):
         return -self.amount
 
+    @attributes(short_description=_("source registration"))
     @cached_property
     def registration(self):
         return self.source_registration
 
-    registration.short_description = _("source registration")
-
 
 @receiver(models.signals.post_save, sender=PaysPayment)
 def payment_create_subject_payment(instance, **kwargs):
