@@ -3,11 +3,10 @@ from traceback import print_exc
 
 import requests
 from django import template
-from django.contrib.admin.templatetags.admin_list import (
-    result_list as _result_list,
-)
+from django.contrib.admin.templatetags.admin_list import result_list as _result_list
 from django.contrib.staticfiles import finders
 from django.core.cache import InvalidCacheBackendError, caches
+from django.core.paginator import Paginator
 from django.urls import reverse
 from django.utils import timezone
 from django.utils.formats import date_format
@@ -18,9 +17,12 @@ from lxml.html import fromstring, tostring
 from ..conf import settings
 from ..forms.schoolyear import SchoolYearForm
 from ..utils import (
-    comma_separated as _comma_separated, currency as _currency,
-    current_url as _current_url, first_upper as _first_upper,
-    url_back as _url_back, url_with_back as _url_with_back,
+    comma_separated as _comma_separated,
+    currency as _currency,
+    current_url as _current_url,
+    first_upper as _first_upper,
+    url_back as _url_back,
+    url_with_back as _url_with_back,
 )
 
 register = template.Library()
@@ -31,7 +33,7 @@ def currency(value):
     try:
         return _currency(value)
     except (ValueError, TypeError):
-        return ''
+        return ""
 
 
 @register.filter
@@ -39,11 +41,12 @@ def comma_separated(value):
     return _comma_separated(value)
 
 
-@register.inclusion_tag('leprikon/admin/dashboard.html', takes_context=True)
+@register.inclusion_tag("leprikon/admin/dashboard.html", takes_context=True)
 def dashboard(context):
     from ..models.subjects import SubjectType
+
     context = context.__copy__()
-    context['subject_types'] = SubjectType.objects.all()
+    context["subject_types"] = SubjectType.objects.all()
     return context
 
 
@@ -60,7 +63,7 @@ def filter_current_school_year(value, school_year):
 @register.filter
 def lines(value):
     try:
-        return value.strip().split('\n')
+        return value.strip().split("\n")
     except Exception:
         return []
 
@@ -68,9 +71,15 @@ def lines(value):
 @register.filter
 def jsdate(d):
     try:
-        return f'new Date({d.year},{d.month-1},{d.day})'
+        return f"new Date({d.year},{d.month-1},{d.day})"
     except AttributeError:
-        return 'undefined'
+        return "undefined"
+
+
+@register.filter
+def paginator(items, per_page=1):
+    paginator = Paginator(items, per_page)
+    return [paginator.page(page) for page in paginator.page_range]
 
 
 @register.simple_tag
@@ -80,77 +89,77 @@ def param_back():
 
 @register.simple_tag(takes_context=True)
 def url_back(context):
-    return _url_back(context['request'])
+    return _url_back(context["request"])
 
 
 @register.simple_tag(takes_context=True)
 def current_url(context):
-    return _current_url(context['request'])
+    return _current_url(context["request"])
 
 
-@register.inclusion_tag('leprikon/registration_links.html', takes_context=True)
+@register.inclusion_tag("leprikon/registration_links.html", takes_context=True)
 def registration_links(context, subject):
     now = timezone.now()
     context = context.__copy__()
-    context['subject'] = subject
-    if context['request'].user.is_authenticated():
-        context['registrations'] = subject.registrations.filter(user=context['request'].user, canceled=None)
+    context["subject"] = subject
+    if context["request"].user.is_authenticated():
+        context["registrations"] = subject.registrations.filter(user=context["request"].user, canceled=None)
     else:
-        context['registrations'] = []
+        context["registrations"] = []
 
     try:
-        registration_link = context['view'].registration_link
+        registration_link = context["view"].registration_link
     except (AttributeError, KeyError):
         registration_link = None
 
     if registration_link:
         source = registration_link
-        context['registration_url'] = _url_with_back(
-            reverse('leprikon:registration_link_form', args=(registration_link.slug, subject.id)),
+        context["registration_url"] = _url_with_back(
+            reverse("leprikon:registration_link_form", args=(registration_link.slug, subject.id)),
             current_url(context),
         )
     else:
         source = subject
-        context['registration_url'] = _url_with_back(subject.get_registration_url(), current_url(context))
+        context["registration_url"] = _url_with_back(subject.get_registration_url(), current_url(context))
 
-    context['registration_allowed'] = source.registration_allowed
+    context["registration_allowed"] = source.registration_allowed
 
-    if context['registration_allowed']:
-        context['registration_message'] = ''
+    if context["registration_allowed"]:
+        context["registration_message"] = ""
     else:
-        context['registration_message'] = _('Registering is currently not allowed.')
+        context["registration_message"] = _("Registering is currently not allowed.")
 
     if subject.price and source.reg_to:
-        context['registration_ended_message'] = _('Registering ended on {}').format(
-            date_format(timezone.localtime(source.reg_to), 'DATETIME_FORMAT')
+        context["registration_ended_message"] = _("Registering ended on {}").format(
+            date_format(timezone.localtime(source.reg_to), "DATETIME_FORMAT")
         )
         if source.reg_to > now:
-            context['registration_end_in'] = (source.reg_to - now).seconds
-            context['registration_ends_message'] = _('Registering will end on {}.').format(
-                date_format(timezone.localtime(source.reg_to), 'DATETIME_FORMAT')
+            context["registration_end_in"] = (source.reg_to - now).seconds
+            context["registration_ends_message"] = _("Registering will end on {}.").format(
+                date_format(timezone.localtime(source.reg_to), "DATETIME_FORMAT")
             )
-            context['registration_message'] = context['registration_ends_message']
+            context["registration_message"] = context["registration_ends_message"]
         else:
-            context['registration_message'] = context['registration_ended_message']
+            context["registration_message"] = context["registration_ended_message"]
     if subject.price and source.reg_from and source.reg_from > now:
-        context['registration_start_in'] = (source.reg_from - now).seconds
-        context['registration_starts_message'] = _('Registering will start on {}.').format(
-            date_format(timezone.localtime(source.reg_from), 'DATETIME_FORMAT')
+        context["registration_start_in"] = (source.reg_from - now).seconds
+        context["registration_starts_message"] = _("Registering will start on {}.").format(
+            date_format(timezone.localtime(source.reg_from), "DATETIME_FORMAT")
         )
-        context['registration_message'] = context['registration_starts_message']
+        context["registration_message"] = context["registration_starts_message"]
     return context
 
 
-@register.inclusion_tag('leprikon/schoolyear_form.html', takes_context=True)
+@register.inclusion_tag("leprikon/schoolyear_form.html", takes_context=True)
 def school_year_form(context):
     context = context.__copy__()
-    context['school_year_form'] = SchoolYearForm(context.get('request'))
+    context["school_year_form"] = SchoolYearForm(context.get("request"))
     return context
 
 
 @register.simple_tag
 def upstream(url, xpath, *replacements):
-    '''
+    """
     If Leprikón is intended to look like another website (the main website of the organization),
     use this tag to include html snippet from the other site to always stay aligned with it.
 
@@ -159,11 +168,11 @@ def upstream(url, xpath, *replacements):
         {% load cache leprikon_tags %}
         {% cache 300 menu %}{% upstream 'https://example.com/' '//nav' %}{% endcache %}
         {% cache 300 menu %}{% upstream 'https://example.com/' '//nav' '|<br>|<br/>|' %}{% endcache %}
-    '''
+    """
     try:
-        cache = caches['upstream_pages']
+        cache = caches["upstream_pages"]
     except InvalidCacheBackendError:
-        cache = caches['default']
+        cache = caches["default"]
     try:
         content = cache.get(url)
         if content is None:
@@ -171,19 +180,16 @@ def upstream(url, xpath, *replacements):
             cache.set(url, content, 60)
         for replacement in replacements:
             try:
-                replacement = replacement.encode('utf-8')
+                replacement = replacement.encode("utf-8")
                 pattern, repl = replacement[1:-1].split(replacement[:1])
             except (IndexError, ValueError):
                 print_exc()
             else:
                 content = re.sub(pattern, repl, content)
-        return mark_safe(b''.join(
-            tostring(node)
-            for node in fromstring(content).xpath(xpath)
-        ))
+        return mark_safe(b"".join(tostring(node) for node in fromstring(content).xpath(xpath)))
     except Exception:
         print_exc()
-        return ''
+        return ""
 
 
 class URLWithBackNode(template.base.Node):
@@ -208,7 +214,7 @@ def url_with_back(parser, token):
 
 @register.simple_tag(takes_context=True)
 def query_string(context, key, value):
-    get = context['request'].GET.copy()
+    get = context["request"].GET.copy()
     get[key] = value
     return get.urlencode()
 
@@ -218,10 +224,10 @@ def font(name):
     return finders.find(name)
 
 
-@register.inclusion_tag('admin/change_list_results.html')
+@register.inclusion_tag("admin/change_list_results.html")
 def css_result_list(cl):
     context = _result_list(cl)
-    if hasattr(cl.model_admin, 'get_css'):
-        for result, obj in zip(context['results'], cl.result_list):
+    if hasattr(cl.model_admin, "get_css"):
+        for result, obj in zip(context["results"], cl.result_list):
             result.css = cl.model_admin.get_css(obj)
     return context
